@@ -1,8 +1,8 @@
 package Getopt::EX::Colormap;
 
+use v5.014;
 use strict;
 use warnings;
-use Graphics::ColorNames;
 
 use Exporter 'import';
 our @EXPORT      = qw();
@@ -84,8 +84,6 @@ my %numbers = (
     W => 37, w => 97,	# W : White
     );
 
-tie my %color_table, 'Graphics::ColorNames', qw(WWW);
-
 sub rgb24 {
     my $rgb = shift;
     if ($COLOR_RGB24) {
@@ -172,7 +170,11 @@ sub ansi_numbers {
 	    };
 	}
 	elsif ($+{name}) {
-	    if (my $rgb = $color_table{$+{name}}) {
+	    state $colornames = do {
+		require Graphics::ColorNames;
+		new     Graphics::ColorNames;
+	    };
+	    if (my $rgb = $colornames->hex($+{name})) {
 		push @numbers, 38 + $toggle->value, rgb24($rgb);
 	    } else {
 		die "Unknown color name: $+{name}\n";
@@ -567,35 +569,87 @@ C<{SGR1;30;48;5;224}> or more readable C<{SGR(1,30,48,5,224)}>.
 =head1 COLOR NAMES
 
 Color names are experimentaly supported in this version.  Currently
-names are listed in L<Graphics::ColorNames::WWW> module.  Following
+names are listed in L<Graphics::ColorNames::X> module.  Following
 colors are available.
 
-=over 4
+See L<https://en.wikipedia.org/wiki/X11_color_names>.
 
-aliceblue antiquewhite aqua aquamarine azure beige bisque black
-blanchedalmond blue blueviolet brown burlywood cadetblue chartreuse
-chocolate coral cornflowerblue cornsilk crimson cyan darkblue darkcyan
-darkgoldenrod darkgray darkgreen darkgrey darkkhaki darkmagenta
-darkolivegreen darkorange darkorchid darkred darksalmon darkseagreen
-darkslateblue darkslategray darkslategrey darkturquoise darkviolet
-deeppink deepskyblue dimgray dimgrey dodgerblue firebrick floralwhite
-forestgreen fuchsia fuscia gainsboro ghostwhite gold goldenrod gray
-grey green greenyellow honeydew hotpink indianred indigo ivory khaki
-lavender lavenderblush lawngreen lemonchiffon lightblue lightcoral
-lightcyan lightgoldenrodyellow lightgray lightgreen lightgrey
-lightpink lightsalmon lightseagreen lightskyblue lightslategray
-lightslategrey lightsteelblue lightyellow lime limegreen linen magenta
-maroon mediumaquamarine mediumblue mediumorchid mediumpurple
-mediumseagreen mediumslateblue mediumspringgreen mediumturquoise
-mediumvioletred midnightblue mintcream mistyrose moccasin navajowhite
-navy oldlace olive olivedrab orange orangered orchid palegoldenrod
-palegreen paleturquoise palevioletred papayawhip peachpuff peru pink
-plum powderblue purple red rosybrown royalblue saddlebrown salmon
-sandybrown seagreen seashell sienna silver skyblue slateblue slategray
-slategrey snow springgreen steelblue tan teal thistle tomato turquoise
-violet wheat white whitesmoke yellow yellowgreen
+    gray gray0 .. gray100
+    grey grey0 .. grey100
 
-=back
+    aliceblue antiquewhite antiquewhite1 antiquewhite2 antiquewhite3
+    antiquewhite4 aqua aquamarine aquamarine1 aquamarine2 aquamarine3
+    aquamarine4 azure azure1 azure2 azure3 azure4 beige bisque bisque1
+    bisque2 bisque3 bisque4 black blanchedalmond blue blue1 blue2 blue3
+    blue4 blueviolet brown brown1 brown2 brown3 brown4 burlywood
+    burlywood1 burlywood2 burlywood3 burlywood4 cadetblue cadetblue1
+    cadetblue2 cadetblue3 cadetblue4 chartreuse chartreuse1 chartreuse2
+    chartreuse3 chartreuse4 chocolate chocolate1 chocolate2 chocolate3
+    chocolate4 coral coral1 coral2 coral3 coral4 cornflowerblue cornsilk
+    cornsilk1 cornsilk2 cornsilk3 cornsilk4 crimson cyan cyan1 cyan2 cyan3
+    cyan4 darkblue darkcyan darkgoldenrod darkgoldenrod1 darkgoldenrod2
+    darkgoldenrod3 darkgoldenrod4 darkgray darkgreen darkgrey darkkhaki
+    darkmagenta darkolivegreen darkolivegreen1 darkolivegreen2
+    darkolivegreen3 darkolivegreen4 darkorange darkorange1 darkorange2
+    darkorange3 darkorange4 darkorchid darkorchid1 darkorchid2 darkorchid3
+    darkorchid4 darkred darksalmon darkseagreen darkseagreen1
+    darkseagreen2 darkseagreen3 darkseagreen4 darkslateblue darkslategray
+    darkslategray1 darkslategray2 darkslategray3 darkslategray4
+    darkslategrey darkturquoise darkviolet deeppink deeppink1 deeppink2
+    deeppink3 deeppink4 deepskyblue deepskyblue1 deepskyblue2 deepskyblue3
+    deepskyblue4 dimgray dimgrey dodgerblue dodgerblue1 dodgerblue2
+    dodgerblue3 dodgerblue4 firebrick firebrick1 firebrick2 firebrick3
+    firebrick4 floralwhite forestgreen fuchsia gainsboro ghostwhite gold
+    gold1 gold2 gold3 gold4 goldenrod goldenrod1 goldenrod2 goldenrod3
+    goldenrod4 honeydew honeydew1 honeydew2 honeydew3 honeydew4 hotpink
+    hotpink1 hotpink2 hotpink3 hotpink4 indianred indianred1 indianred2
+    indianred3 indianred4 indigo ivory ivory1 ivory2 ivory3 ivory4 khaki
+    khaki1 khaki2 khaki3 khaki4 lavender lavenderblush lavenderblush1
+    lavenderblush2 lavenderblush3 lavenderblush4 lawngreen lemonchiffon
+    lemonchiffon1 lemonchiffon2 lemonchiffon3 lemonchiffon4 lightblue
+    lightblue1 lightblue2 lightblue3 lightblue4 lightcoral lightcyan
+    lightcyan1 lightcyan2 lightcyan3 lightcyan4 lightgoldenrod
+    lightgoldenrod1 lightgoldenrod2 lightgoldenrod3 lightgoldenrod4
+    lightgoldenrodyellow lightgray lightgreen lightgrey lightpink
+    lightpink1 lightpink2 lightpink3 lightpink4 lightsalmon lightsalmon1
+    lightsalmon2 lightsalmon3 lightsalmon4 lightseagreen lightskyblue
+    lightskyblue1 lightskyblue2 lightskyblue3 lightskyblue4 lightslateblue
+    lightslategray lightslategrey lightsteelblue lightsteelblue1
+    lightsteelblue2 lightsteelblue3 lightsteelblue4 lightyellow
+    lightyellow1 lightyellow2 lightyellow3 lightyellow4 lime limegreen
+    linen magenta magenta1 magenta2 magenta3 magenta4 maroon maroon1
+    maroon2 maroon3 maroon4 mediumaquamarine mediumblue mediumorchid
+    mediumorchid1 mediumorchid2 mediumorchid3 mediumorchid4 mediumpurple
+    mediumpurple1 mediumpurple2 mediumpurple3 mediumpurple4 mediumseagreen
+    mediumslateblue mediumspringgreen mediumturquoise mediumvioletred
+    midnightblue mintcream mistyrose mistyrose1 mistyrose2 mistyrose3
+    mistyrose4 moccasin navajowhite navajowhite1 navajowhite2 navajowhite3
+    navajowhite4 navy navyblue oldlace olive olivedrab olivedrab1
+    olivedrab2 olivedrab3 olivedrab4 orange orange1 orange2 orange3
+    orange4 orangered orangered1 orangered2 orangered3 orangered4 orchid
+    orchid1 orchid2 orchid3 orchid4 palegoldenrod palegreen palegreen1
+    palegreen2 palegreen3 palegreen4 paleturquoise paleturquoise1
+    paleturquoise2 paleturquoise3 paleturquoise4 palevioletred
+    palevioletred1 palevioletred2 palevioletred3 palevioletred4 papayawhip
+    peachpuff peachpuff1 peachpuff2 peachpuff3 peachpuff4 peru pink pink1
+    pink2 pink3 pink4 plum plum1 plum2 plum3 plum4 powderblue purple
+    purple1 purple2 purple3 purple4 rebeccapurple red red1 red2 red3 red4
+    rosybrown rosybrown1 rosybrown2 rosybrown3 rosybrown4 royalblue
+    royalblue1 royalblue2 royalblue3 royalblue4 saddlebrown salmon salmon1
+    salmon2 salmon3 salmon4 sandybrown seagreen seagreen1 seagreen2
+    seagreen3 seagreen4 seashell seashell1 seashell2 seashell3 seashell4
+    sienna sienna1 sienna2 sienna3 sienna4 silver skyblue skyblue1
+    skyblue2 skyblue3 skyblue4 slateblue slateblue1 slateblue2 slateblue3
+    slateblue4 slategray slategray1 slategray2 slategray3 slategray4
+    slategrey snow snow1 snow2 snow3 snow4 springgreen springgreen1
+    springgreen2 springgreen3 springgreen4 steelblue steelblue1 steelblue2
+    steelblue3 steelblue4 tan tan1 tan2 tan3 tan4 teal thistle thistle1
+    thistle2 thistle3 thistle4 tomato tomato1 tomato2 tomato3 tomato4
+    turquoise turquoise1 turquoise2 turquoise3 turquoise4 violet violetred
+    violetred1 violetred2 violetred3 violetred4 webgray webgreen webgrey
+    webmaroon webpurple wheat wheat1 wheat2 wheat3 wheat4 white whitesmoke
+    x11gray x11green x11grey x11maroon x11purple yellow yellow1 yellow2
+    yellow3 yellow4 yellowgreen
 
 Enclose them by angle bracket to use, like:
 
@@ -763,6 +817,8 @@ behaviour.
 L<Getopt::EX>,
 L<Getopt::EX::LabeledParam>
 
-L<Graphics::ColorNames::WWW>
-
 L<https://en.wikipedia.org/wiki/ANSI_escape_code>
+
+L<Graphics::ColorNames::X>
+
+L<https://en.wikipedia.org/wiki/X11_color_names>
